@@ -15,6 +15,8 @@ Examples of this sort of event are:
 """
 
 from mitosheet.updates.undo import UNDO_UPDATE
+from mitosheet.updates.redo import REDO_UPDATE
+from mitosheet.updates.clear import CLEAR_UPDATE
 from mitosheet.updates.args_update import ARGS_UPDATE
 from mitosheet.updates.save_analysis import SAVE_ANALYSIS_UPDATE
 from mitosheet.updates.replay_analysis import REPLAY_ANALYSIS_UPDATE
@@ -24,9 +26,12 @@ from mitosheet.updates.set_user_field_update import SET_USER_FIELD_UPDATE
 from mitosheet.updates.checkout_step_by_idx import CHECKOUT_STEP_BY_IDX_UPDATE
 from mitosheet.updates.append_user_field import APPEND_USER_FIELD_UPDATE
 
+
 # All update events must be listed in this variable.
 UPDATES = [
     UNDO_UPDATE,
+    REDO_UPDATE,
+    CLEAR_UPDATE,
     ARGS_UPDATE,
     SAVE_ANALYSIS_UPDATE,
     REPLAY_ANALYSIS_UPDATE,
