@@ -8,7 +8,7 @@
 Deletes an existing saved analysis.
 """
 
-from mitosheet.save_utils import delete_saved_analysis
+from mitosheet.saved_analyses import delete_saved_analysis
 
 DELETE_SAVED_ANALYSIS_UPDATE_EVENT = 'delete_analysis_update'
 DELETE_SAVED_ANALYSIS_UPDATE_PARAMS = [
@@ -16,7 +16,7 @@ DELETE_SAVED_ANALYSIS_UPDATE_PARAMS = [
 ]
 
 def execute_delete_saved_analysis_update(
-        wsc,
+        steps_manager,
         analysis_name,
     ):
     """
